@@ -296,6 +296,10 @@ enum
 #define SIZE_GRIP_SIZE 12
 
 #define USE_LIGHTER_POPUP_MENU (opts.lighterPopupMenuBgnd)
+#define USE_BORDER(B)          (GB_SHINE!=(B) && GB_NONE!=(B))
+#define DRAW_MENU_BORDER       (APPEARANCE_FLAT!=opts.menuBgndAppearance && opts.version>=MAKE_VERSION(1,7) && \
+                                USE_BORDER(getGradient(opts.menuBgndAppearance, &opts)->border))
+
 #define USE_GLOW_FOCUS(mouseOver) (FOCUS_GLOW==opts.focus && (MO_GLOW!=opts.coloredMouseOver || !(mouseOver)))
 
 #define USE_SHADED_MENU_BAR_COLORS (SHADE_CUSTOM==opts.shadeMenubars || SHADE_BLEND_SELECTED==opts.shadeMenubars)
@@ -550,6 +554,32 @@ typedef enum
     IMG_FILE
 } EImageType;
 
+typedef struct
+{
+#if defined __cplusplus
+    TQString   file;
+    TQPixmap   img;
+#else // __cplusplus
+    const char *file;
+    GdkPixbuf *img;
+#endif // __cplusplus
+} TQtCPixmap;
+
+#define BGND_IMG_ON_BORDER (IMG_FILE==opts.bgndImage.type && opts.bgndImage.onBorder)
+
+typedef enum
+{
+    PP_TL,
+    PP_TM,
+    PP_TR,
+    PP_BL,
+    PP_BM,
+    PP_BR,
+    PP_LM,
+    PP_RM,
+    PP_CENTRED,
+} EPixPos;
+
 typedef struct
 {
     EImageType type;
@@ -564,6 +594,13 @@ typedef struct
     int width, height;
 } TQtCImage;
 
+typedef enum
+{
+    THIN_BUTTONS    = 0x0001,
+    THIN_MENU_ITEMS = 0x0002,
+    THIN_FRAMES     = 0x0004
+} EThinFlags;
+
 typedef enum
 {
     SQUARE_NONE               = 0x0000,
@@ -713,6 +750,7 @@ typedef enum
         APPEARANCE_FADE, /* Only for poupmenu items! */
         APPEARANCE_STRIPED = APPEARANCE_FADE, /* Only for windows  and menus */
         APPEARANCE_NONE = APPEARANCE_FADE, /* Only for titlebars */
+        APPEARANCE_FILE,  /* Only for windows  and menus */
         APPEARANCE_LV_BEVELLED, /* To be used only with getGradient */
         APPEARANCE_AGUA_MOD,
         APPEARANCE_LV_AGUA,
@@ -775,6 +813,13 @@ typedef enum
     TB_DARK_ALL
 } ETBarBorder;
 
+typedef enum
+{
+    TBTN_STANDARD,
+    TBTN_RAISED,
+    TBTN_JOINED
+} ETBarBtn;
+
 typedef enum
 {
     BORDER_FLAT,
@@ -1056,7 +1101,10 @@ typedef struct
                      splitterHighlight,
                      crSize,
                      gbFactor,
-                     gbLabel;
+                     gbLabel,
+                     thin,
+                     tbarBtnAppearance,
+                     tbarBtnEffect;
     ERound           round;
     bool             embolden,
                      highlightTab,
@@ -1078,6 +1126,7 @@ typedef struct
                      gtkScrollViews,
                      stdSidebarButtons,
                      toolbarTabs,
+                     hideShortcutUnderline,
 #ifdef __cplusplus
                      gtkComboMenus,
 /*
@@ -1088,8 +1137,8 @@ typedef struct
                      mapKdeIcons,
 #if defined CONFIG_DIALOG || ( defined QT4_OR_ABOVE) || !defined __cplusplus
                      gtkButtonOrder,
-                     fadeLines,
 #endif
+                     fadeLines,
                      reorderGtkButtons,
                      borderMenuitems,
                      colorMenubarMouseOver,
@@ -1154,6 +1203,7 @@ typedef struct
     ESliderStyle     sliderStyle;
     EMouseOver       coloredMouseOver;
     ETBarBorder      toolbarBorders;
+    ETBarBtn         tbarBtns;
     EDefBtnIndicator defBtnIndicator;
     ELine            sliderThumbs,
                      handles,
@@ -1221,6 +1271,8 @@ typedef struct
 #else
     Gradient         *customGradient[NUM_CUSTOM_GRAD];
 #endif
+    TQtCPixmap        bgndPixmap;
+    TQtCPixmap        menuBgndPixmap;
     TQtCImage         bgndImage,
                      menuBgndImage;
 #if !defined __cplusplus || ( defined QT4_OR_ABOVE)
