@@ -799,7 +799,7 @@ QtCurveConfig::~QtCurveConfig()
 
 void QtCurveConfig::loadStyles(TQPopupMenu *menu)
 {
-    TQStringList  files(TDEGlobal::dirs()->findAllResources("data", "QtCurve/*"EXTENSION, false, true));
+    TQStringList  files(TDEGlobal::dirs()->findAllResources("data", "QtCurve/*" EXTENSION, false, true));
 
     files.sort();
 
@@ -1374,9 +1374,11 @@ void QtCurveConfig::roundChanged()
 void QtCurveConfig::importStyle()
 {
     TQString file(KFileDialog::getOpenFileName(TQString::null,
-                                              i18n("*"EXTENSION"|QtCurve Settings Files\n"
-                                                   THEME_PREFIX"*"THEME_SUFFIX"|QtCurve TDE Theme Files"),
-                                              this));
+                                               TQString("*%1|").arg(EXTENSION)+
+                                               i18n("QtCurve Settings Files") + "\n" +
+                                               TQString("%1*%2|").arg(THEME_PREFIX).arg(THEME_SUFFIX)+
+                                               i18n("QtCurve TDE Theme Files"),
+                                               this));
 
     if(!file.isEmpty())
         loadStyle(file);
@@ -1384,7 +1386,7 @@ void QtCurveConfig::importStyle()
 
 void QtCurveConfig::exportStyle()
 {
-    TQString file(KFileDialog::getSaveFileName(TQString::null, i18n("*"EXTENSION"|QtCurve Settings Files"), this));
+    TQString file(KFileDialog::getSaveFileName(TQString::null, TQString("*%1|").arg(EXTENSION)+i18n("QtCurve Settings Files"), this));
 
     if(!file.isEmpty())
     {
